@@ -1,7 +1,7 @@
 /**
  * @file comments.c comment feed handling
  * 
- * Copyright (C) 2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2007-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,14 +19,16 @@
  */
 
 #include <string.h>
+
 #include "comments.h"
 #include "common.h"
 #include "db.h"
 #include "debug.h"
 #include "feed.h"
-#include "itemview.h"
 #include "metadata.h"
+#include "net.h"
 #include "update.h"
+#include "ui/itemview.h"
 
 /* Comment feeds in Liferea are simple flat lists of items attached
    to a single item. Each item that has a comment feed URL in its 
@@ -123,11 +125,10 @@ comments_process_update_result (const struct updateResult * const result, gpoint
 		debug1(DEBUG_UPDATE, "received update result for comment feed \"%s\"", result->source);
 
 		/* parse the new downloaded feed into fake node, subscription and feed */
-		node = node_new ();
+		node = node_new (feed_get_node_type ());
 		ctxt = feed_create_parser_ctxt ();
 		ctxt->subscription = subscription_new (result->source, NULL, NULL);
 		ctxt->feed = feed_new ();
-		node_set_type (node, feed_get_node_type ());
 		node_set_data (node, ctxt->feed);		
 		node_set_subscription (node, ctxt->subscription);
 		ctxt->data = result->data;
@@ -152,7 +153,7 @@ comments_process_update_result (const struct updateResult * const result, gpoint
 			
 			debug1 (DEBUG_UPDATE, "parsing comment feed successful (%d comments downloaded)", g_list_length(ctxt->items));
 			comments = db_itemset_load (commentFeed->id);
-			itemset_merge_items (comments, ctxt->items, ctxt->feed->valid);
+			itemset_merge_items (comments, ctxt->items, ctxt->feed->valid, FALSE);
 			itemset_free (comments);
 			
 			/* No comment feed truncating as comment items are automatically
@@ -167,18 +168,9 @@ comments_process_update_result (const struct updateResult * const result, gpoint
 	g_free (commentFeed->error);
 	commentFeed->error = NULL;
 	
-	if (!(result->httpstatus >= 200) && (result->httpstatus < 400)) {
-		const gchar * tmp;
-		
-		/* first specific codes (guarantees tmp to be set) */
-		tmp = common_http_error_to_str (result->httpstatus);
-
-		/* second netio errors */
-		if (common_netio_error_to_str (result->returncode))
-			tmp = common_netio_error_to_str (result->returncode);
-			
-		commentFeed->error = g_strdup (tmp);
-	}	
+	if ((result->httpstatus < 200) || (result->httpstatus >= 400)) {
+		commentFeed->error = g_strdup (network_strerror (result->returncode, result->httpstatus));
+	}
 
 	/* clean up... */
 	commentFeed->updateJob = NULL;
@@ -199,7 +191,7 @@ comments_refresh (itemPtr item)
 	updateRequestPtr	request;
 	const gchar		*url;
 	
-	if (!update_is_online ())
+	if (!network_is_online ())
 		return;
 	
 	url = metadata_list_get (item->metadata, "commentFeedUri");
@@ -208,11 +200,13 @@ comments_refresh (itemPtr item)
 
 		// FIXME: restore update state from DB?		
 		
-		if (item->commentFeedId)
+		if (item->commentFeedId) {
 			commentFeed = comment_feed_from_id (item->commentFeedId);
-		else
+		} else {
 			item->commentFeedId = node_new_id ();		
-			
+			db_item_update (item);
+		}
+
 		if (!commentFeed) {			
 			commentFeed = g_new0 (struct commentFeed, 1);
 			commentFeed->id = g_strdup (item->commentFeedId);
