@@ -517,7 +517,11 @@ xmlChar * common_build_url(const gchar *url, const gchar *baseURL) {
 	if(NULL != baseURL) {
 		escapedBaseURL = common_uri_escape(baseURL);	
 		absURL = xmlBuildURI(escapedURL, escapedBaseURL);
-		xmlFree(escapedURL);
+		if(absURL)
+			xmlFree(escapedURL);
+		else
+			absURL = escapedURL;
+
 		xmlFree(escapedBaseURL);
 	} else {
 		absURL = escapedURL;
