@@ -1,7 +1,7 @@
 /**
  * @file conf.c Liferea configuration (gconf access)
  *
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004,2005 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,10 +19,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 #include <libxml/uri.h>
@@ -32,16 +28,15 @@
 #include "common.h"
 #include "conf.h"
 #include "debug.h"
+#include "net.h"
 #include "update.h"
-#include "ui/ui_mainwindow.h"
+#include "ui/liferea_shell.h"
 #include "ui/ui_tray.h"
 
 #define MAX_GCONF_PATHLEN	256
 
 #define PATH		"/apps/liferea"
 
-#define HOMEPAGE	"http://liferea.sf.net/"
-
 static GConfClient	*client;
 
 /* Function prototypes */
@@ -49,11 +44,12 @@ static void conf_proxy_reset_settings_cb(GConfClient *client, guint cnxn_id, GCo
 static void conf_tray_settings_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data);
 static void conf_toolbar_style_settings_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data);
 
-static gboolean is_gconf_error(GError **err) {
-
-	if(*err != NULL) {
-		g_warning("%s\n", (*err)->message);
-		g_error_free(*err);
+static gboolean
+is_gconf_error (GError **err)
+{
+	if (*err) {
+		g_warning ("%s\n", (*err)->message);
+		g_error_free (*err);
 		*err = NULL;
 		return TRUE;
 	}
@@ -62,33 +58,27 @@ static gboolean is_gconf_error(GError **err) {
 }
 
 /* called once on startup */
-void conf_init() {
-	
-	/* Construct the User-Agent string of Liferea. This is done here in program init,
-	   because we need to do it exactly once and it will never change while the program
-	   is running. */
-	if (g_getenv("LANG") != NULL) {
-		/* e.g. Liferea/0.3.8 (Linux; de_DE; (http://liferea.sf.net/) */
-		network_set_user_agent (g_strdup_printf("Liferea/%s (%s; %s; %s)", VERSION, OSNAME, g_getenv("LANG"), HOMEPAGE));
-	} else {
-		/* "Liferea/" + VERSION + "(" OS + "; " + HOMEPAGE + ")" */
-		network_set_user_agent( g_strdup_printf("Liferea/%s (%s; %s)", VERSION, OSNAME, HOMEPAGE));
-	}
+void
+conf_init (void)
+{	
+	/* call g_type_init(), GConf for some reason refuses to do so itself 
+	   and we use GConf before initializing GTK which would call g_type_init() itself */
+	g_type_init ();
 	
 	/* initialize GConf client */
-	client = gconf_client_get_default();
-	gconf_client_add_dir(client, PATH, GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_add_dir(client, "/apps/liferea/proxy", GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_add_dir(client, "/system/http_proxy", GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_add_dir(client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_NONE, NULL);
+	client = gconf_client_get_default ();
+	gconf_client_add_dir (client, PATH, GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_add_dir (client, "/apps/liferea/proxy", GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_add_dir (client, "/system/http_proxy", GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_add_dir (client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_NONE, NULL);
 	
-	gconf_client_notify_add(client, "/apps/liferea/proxy", conf_proxy_reset_settings_cb, NULL, NULL, NULL);
-	gconf_client_notify_add(client, "/system/http_proxy", conf_proxy_reset_settings_cb, NULL, NULL, NULL);
-	gconf_client_notify_add(client, "/desktop/gnome/interface/toolbar_style", conf_toolbar_style_settings_cb, NULL, NULL, NULL);
-	gconf_client_notify_add(client, SHOW_TRAY_ICON, conf_tray_settings_cb, NULL, NULL, NULL);
+	gconf_client_notify_add (client, "/apps/liferea/proxy", conf_proxy_reset_settings_cb, NULL, NULL, NULL);
+	gconf_client_notify_add (client, "/system/http_proxy", conf_proxy_reset_settings_cb, NULL, NULL, NULL);
+	gconf_client_notify_add (client, "/desktop/gnome/interface/toolbar_style", conf_toolbar_style_settings_cb, NULL, NULL, NULL);
+	gconf_client_notify_add (client, SHOW_TRAY_ICON, conf_tray_settings_cb, NULL, NULL, NULL);
 	
 	/* Load settings into static buffers */
-	conf_proxy_reset_settings_cb(NULL, 0, NULL, NULL);
+	conf_proxy_reset_settings_cb (NULL, 0, NULL, NULL);
 }
 
 void
@@ -98,27 +88,31 @@ conf_deinit (void)
 }
 
 /* maybe called several times to reload configuration */
-void conf_load(void)
+void
+conf_load (void)
 {
 	gint	maxitemcount;
 	gchar *downloadPath;
 	
 	/* check if important preferences exist... */
-	if(0 == (maxitemcount = conf_get_int_value(DEFAULT_MAX_ITEMS)))
-		conf_set_int_value(DEFAULT_MAX_ITEMS, 100);
+	if (0 == (maxitemcount = conf_get_int_value (DEFAULT_MAX_ITEMS)))
+		conf_set_int_value (DEFAULT_MAX_ITEMS, 100);
 	
-	downloadPath = conf_get_str_value(ENCLOSURE_DOWNLOAD_PATH);
-	if(0 == strcmp("", downloadPath))
-		conf_set_str_value(ENCLOSURE_DOWNLOAD_PATH, g_getenv("HOME"));
-	g_free(downloadPath);
+	downloadPath = conf_get_str_value (ENCLOSURE_DOWNLOAD_PATH);
+	if (!strcmp ("", downloadPath))
+		conf_set_str_value (ENCLOSURE_DOWNLOAD_PATH, g_getenv ("HOME"));
+	g_free (downloadPath);
 }
 
-static void conf_tray_settings_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data) {
+static void
+conf_tray_settings_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
 	GConfValue *value;
-	if (entry != NULL) {
-		value = gconf_entry_get_value(entry);
-		if (value != NULL && value->type == GCONF_VALUE_BOOL)
-			ui_tray_enable(gconf_value_get_bool(value));
+	
+	if (entry) {
+		value = gconf_entry_get_value (entry);
+		if (value && value->type == GCONF_VALUE_BOOL)
+			ui_tray_enable (gconf_value_get_bool (value));
 	}
 }
 
@@ -128,10 +122,10 @@ conf_toolbar_style_settings_cb (GConfClient *client,
                                 GConfEntry *entry,
                                 gpointer user_data) 
 {
-	gchar *style = conf_get_toolbar_style();
+	gchar *style = conf_get_toolbar_style ();
 
-	if (style != NULL) {
-		ui_mainwindow_set_toolbar_style (style);
+	if (style) {
+		liferea_shell_set_toolbar_style (style);
 		g_free (style);
 	}
 }
@@ -156,13 +150,13 @@ conf_proxy_reset_settings_cb (GConfClient *client,
 		default:
 		case 0:
 			debug0 (DEBUG_CONF, "proxy auto detect is configured");
-				
+
 			/* first check for a configured GNOME proxy, note: older
 			   GNOME versions do use the boolean flag GNOME_USE_PROXY
 			   while newer ones use the string key GNOME_PROXY_MODE */
 			tmp = conf_get_str_value (GNOME_PROXY_MODE);
 			gnomeUseProxy = conf_get_bool_value (GNOME_USE_PROXY) || g_str_equal (tmp, "manual");
-			g_free (tmp);
+			g_free (tmp);				
 			
 			/* first check for a configured GNOME proxy */
 			if (gnomeUseProxy) {
@@ -228,98 +222,109 @@ conf_proxy_reset_settings_cb (GConfClient *client,
 		  proxyusername != NULL ? proxyusername : "NULL",
 		  proxypassword != NULL ? proxypassword : "NULL");
 		  
-	network_set_proxy (proxyname, proxyport);
-	network_set_proxy_auth (proxyusername, proxypassword);
+	network_set_proxy (proxyname, proxyport, proxyusername, proxypassword);
 }
 
 /*----------------------------------------------------------------------*/
 /* generic configuration access methods					*/
 /*----------------------------------------------------------------------*/
 
-void conf_set_bool_value(const gchar *valuename, gboolean value) {
+void
+conf_set_bool_value (const gchar *valuename, gboolean value)
+{
 	GError		*err = NULL;
 	GConfValue	*gcv;
 	
-	g_assert(valuename != NULL);
+	g_assert (valuename != NULL);
 	
-	gcv = gconf_value_new(GCONF_VALUE_BOOL);
-	gconf_value_set_bool(gcv, value);
-	gconf_client_set(client, valuename, gcv, &err);
-	gconf_value_free(gcv);
-	is_gconf_error(&err);
+	gcv = gconf_value_new (GCONF_VALUE_BOOL);
+	gconf_value_set_bool (gcv, value);
+	gconf_client_set (client, valuename, gcv, &err);
+	gconf_value_free (gcv);
+	is_gconf_error (&err);
 }
 
-gboolean conf_get_bool_value(const gchar *valuename) {
+gboolean
+conf_get_bool_value (const gchar *valuename)
+{
 	GConfValue	*value = NULL;
 	gboolean	result;
 
-	g_assert(valuename != NULL);
+	g_assert (valuename != NULL);
 
-	value = gconf_client_get(client, valuename, NULL);
-	if(NULL == value) {
-		conf_set_bool_value(valuename, FALSE);
+	value = gconf_client_get (client, valuename, NULL);
+	if (!value) {
+		conf_set_bool_value (valuename, FALSE);
 		result = FALSE;
 	} else {
-		result = gconf_value_get_bool(value);
-		gconf_value_free(value);
+		result = gconf_value_get_bool (value);
+		gconf_value_free (value);
 	}
 		
 	return result;
 }
 
-void conf_set_str_value(const gchar *valuename, const gchar *value) {
+void
+conf_set_str_value (const gchar *valuename, const gchar *value)
+{
 	GError		*err = NULL;
 	GConfValue	*gcv;
 	
-	g_assert(valuename != NULL);
+	g_assert (valuename != NULL);
 	
-	gcv = gconf_value_new(GCONF_VALUE_STRING);
-	gconf_value_set_string(gcv, value);
-	gconf_client_set(client, valuename, gcv, &err);
-	gconf_value_free(gcv);
-	is_gconf_error(&err);
+	gcv = gconf_value_new (GCONF_VALUE_STRING);
+	gconf_value_set_string (gcv, value);
+	gconf_client_set (client, valuename, gcv, &err);
+	gconf_value_free (gcv);
+	is_gconf_error (&err);
 }
 
-gchar * conf_get_str_value(const gchar *valuename) {
+gchar *
+conf_get_str_value (const gchar *valuename)
+{
 	GConfValue	*value = NULL;
 	gchar		*result;
 
-	g_assert(valuename != NULL);
+	g_assert (valuename != NULL);
 		
-	value = gconf_client_get(client, valuename, NULL);
-	if(NULL == value) {
-		result = g_strdup("");
+	value = gconf_client_get (client, valuename, NULL);
+	if (!value) {
+		result = g_strdup ("");
 	} else {
-		result = (gchar *)g_strdup(gconf_value_get_string(value));
-		gconf_value_free(value);
+		result = (gchar *)g_strdup (gconf_value_get_string (value));
+		gconf_value_free (value);
 	}
 		
 	return result;
 }
 
-void conf_set_int_value(const gchar *valuename, gint value) {
+void
+conf_set_int_value (const gchar *valuename, gint value)
+{
 	GError		*err = NULL;
 	GConfValue	*gcv;
 	
-	g_assert(valuename != NULL);
-	debug2(DEBUG_CONF, "Setting %s to %d", valuename, value);
-	gcv = gconf_value_new(GCONF_VALUE_INT);
-	gconf_value_set_int(gcv, value);
-	gconf_client_set(client, valuename, gcv, &err);
-	is_gconf_error(&err);
-	gconf_value_free(gcv);
+	g_assert (valuename != NULL);
+	debug2 (DEBUG_CONF, "Setting %s to %d", valuename, value);
+	gcv = gconf_value_new (GCONF_VALUE_INT);
+	gconf_value_set_int (gcv, value);
+	gconf_client_set (client, valuename, gcv, &err);
+	is_gconf_error (&err);
+	gconf_value_free (gcv);
 }
 
-gint conf_get_int_value(const gchar *valuename) {
+gint
+conf_get_int_value (const gchar *valuename)
+{
 	GConfValue	*value;
 	gint		result = 0;
 
-	g_assert(valuename != NULL);
+	g_assert (valuename != NULL);
 		
-	value = gconf_client_get(client, valuename, NULL);
-	if(NULL != value) {
-		result = gconf_value_get_int(value);
-		gconf_value_free(value);
+	value = gconf_client_get (client, valuename, NULL);
+	if (value) {
+		result = gconf_value_get_int (value);
+		gconf_value_free (value);
 	}
 			
 	return result;
