@@ -37,13 +37,34 @@
 #include "html.h"
 
 typedef struct faviconDownloadCtxt {
-	const gchar		*id;		/**< favicon cache id */
+	gchar		        *id;		/**< favicon cache id */
 	GSList			*urls;		/**< ordered list of URLs to try */
 	updateOptionsPtr	options;	/**< download options */
 	faviconUpdatedCb	callback;	/**< usually feed_favicon_updated() */
 	gpointer		user_data;	/**< usually the node pointer */
 } *faviconDownloadCtxtPtr;
 
+static faviconDownloadCtxtPtr
+favicon_download_ctxt_new () 
+{
+	return g_new0 (struct faviconDownloadCtxt, 1);
+}
+
+static void
+favicon_download_ctxt_free (faviconDownloadCtxtPtr ctxt)
+{
+	GSList  *iter; 
+
+	if (!ctxt) return;
+	g_free (ctxt->id);
+	
+	for (iter = ctxt->urls; iter; iter = g_slist_next (iter))
+		g_free (iter->data);
+
+	g_slist_free (ctxt->urls);
+	update_options_free (ctxt->options);
+}
+
 static void favicon_download_run(faviconDownloadCtxtPtr ctxt);
 
 GdkPixbuf * favicon_load_from_cache(const gchar *id) {
@@ -96,7 +117,7 @@ void favicon_remove_from_cache(const gchar *id) {
 	filename = common_create_cache_filename( "cache" G_DIR_SEPARATOR_S "favicons", id, "png");
 	if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
 		if(0 != unlink(filename))
-			/* What can we do? The file probably doesn't exist. Or permissions are wrong. Oh well.... */;
+			g_warning ("Removal of %s failed", filename);
 	}
 	g_free(filename);
 
@@ -159,8 +180,7 @@ favicon_download_icon_cb (const struct updateResult * const result, gpointer use
 	if (!success) {
 		favicon_download_run (ctxt);	/* try next... */
 	} else {
-		g_slist_free (ctxt->urls);
-		g_free (ctxt);
+		favicon_download_ctxt_free (ctxt);
 	}
 }
 
@@ -210,13 +230,13 @@ favicon_download_run (faviconDownloadCtxtPtr ctxt)
 		else
 			callback = favicon_download_html_cb;
 
-		update_execute_request (ctxt->user_data, request, callback, ctxt, 0);
+		update_execute_request (ctxt->user_data, request, callback, ctxt, FEED_REQ_PRIORITY_HIGH);
 	} else {
 		debug1 (DEBUG_UPDATE, "favicon %s could not be downloaded!", ctxt->id);
 		/* Run favicon-updated callback */
 		if (ctxt->callback)
 			(ctxt->callback) (ctxt->user_data);
-		g_free (ctxt);
+		favicon_download_ctxt_free (ctxt);
 	}
 	
 	debug_exit ("favicon_download_run");
@@ -232,15 +252,15 @@ static gint count_slashes(const gchar *str) {
 	return slashes;
 }
 
-void favicon_download(const gchar *id, const gchar *html_url, const gchar *source_url, updateOptionsPtr options, faviconUpdatedCb callback, gpointer user_data) {
+void favicon_download(const gchar *id, const gchar *html_url, const gchar *source_url, const updateOptionsPtr options, faviconUpdatedCb callback, gpointer user_data) {
 	faviconDownloadCtxtPtr	ctxt;
 	gchar			*tmp, *tmp2;
 	
 	debug_enter("favicon_download");
 	
-	ctxt = g_new0(struct faviconDownloadCtxt, 1);
-	ctxt->id = id;
-	ctxt->options = options;
+	ctxt = favicon_download_ctxt_new ();
+	ctxt->id = g_strdup (id);
+	ctxt->options = update_options_copy (options);
 	ctxt->callback = callback;
 	ctxt->user_data = user_data;
 	
@@ -264,7 +284,7 @@ void favicon_download(const gchar *id, const gchar *html_url, const gchar *sourc
 	
 	/* case 1. */
 	if(html_url) {
-		tmp = g_strdup(html_url);	
+		tmp = g_strstrip (g_strdup(html_url));
 		ctxt->urls = g_slist_append(ctxt->urls, tmp);
 		debug1(DEBUG_UPDATE, "(1) adding favicon search URL: %s", tmp);
 	}
@@ -272,7 +292,7 @@ void favicon_download(const gchar *id, const gchar *html_url, const gchar *sourc
 	/* case 2. */
 	g_assert(source_url);	
 	if(*source_url != '|') {
-		tmp = tmp2 = g_strdup(source_url);
+		tmp = tmp2 = g_strstrip (g_strdup(source_url));
 		tmp = strrchr(tmp, '/');
 		if(tmp) {
 			*tmp = 0;
@@ -283,26 +303,26 @@ void favicon_download(const gchar *id, const gchar *html_url, const gchar *sourc
 	
 	/* case 3. */
 	if(html_url) {
-		tmp = tmp2 = g_strdup(html_url);
-		/* skip protocol prefix */
-		tmp = strstr(tmp, "://");
-		if(tmp) {
-			/* find end of domain name */
-			tmp = strchr(tmp + 3, '/');
-			if(tmp)
-				*tmp = 0;
-				
-			tmp = tmp2;
-			tmp2 = g_strdup_printf("%s/favicon.ico", tmp);
-			ctxt->urls = g_slist_append(ctxt->urls, tmp2);
-			debug1(DEBUG_UPDATE, "(3) adding favicon source URL: %s", tmp2);
+		if(2 < count_slashes(html_url)) {
+			tmp = tmp2 = g_strstrip (g_strdup (html_url));
+			tmp = strstr(tmp, "://");
+			if(tmp) {
+				tmp = strchr(tmp + 3, '/');
+				if(tmp) {
+					*tmp = 0;
+					tmp = tmp2;
+					tmp2 = g_strdup_printf("%s/favicon.ico", tmp);
+					ctxt->urls = g_slist_append(ctxt->urls, tmp2);
+					debug1(DEBUG_UPDATE, "(3) adding favicon source URL: %s", tmp2);
+				}
+			}
+			g_free(tmp);
 		}
-		g_free(tmp);
 	}
 	
 	if(*source_url != '|' && 2 < count_slashes(source_url)) {
 		/* case 4 */
-		tmp = tmp2 = g_strdup(source_url);
+		tmp = tmp2 = g_strstrip (g_strdup (source_url));
 		tmp = strrchr(tmp, '/');
 		if(tmp) {
 			*tmp = 0;
@@ -314,7 +334,7 @@ void favicon_download(const gchar *id, const gchar *html_url, const gchar *sourc
 		g_free(tmp);
 	
 		/* case 5 */
-		tmp = tmp2 = g_strdup(source_url);
+		tmp = tmp2 = g_strstrip (g_strdup (source_url));
 		tmp = strstr(tmp, "://");
 		if(tmp) {
 			tmp = strchr(tmp + 3, '/');	/* to skip to first subpath */
