@@ -1,7 +1,7 @@
 /**
  * @file item.h common item handling
  * 
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2008 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -48,7 +48,6 @@ typedef struct item {
 
 	/* those fields should not be accessed directly. Accessors are provided. */
 	gboolean 	readStatus;		/**< TRUE if the item has been read */
-	gboolean	newStatus;		/**< TRUE if the item was downloaded and is to be counted by the tray icon */
 	gboolean	popupStatus;		/**< TRUE if the item was downloaded and is yet to be displayed by the popup notification feature */
 	gboolean	updateStatus;		/**< TRUE if the item content was updated */
 	gboolean 	flagStatus;		/**< TRUE if the item has been flagged */
@@ -57,8 +56,6 @@ typedef struct item {
 	gchar		*source;		/**< URL to the post online */
 	gchar		*sourceId;		/**< "Unique" syndication item identifier, for example <guid> in RSS */
 	gboolean	validGuid;		/**< TRUE if id of this item is a GUID and can be used for duplicate detection */
-	gchar		*real_source_url;	/**< (optional) URL of the real source (e.g. if listed in search engine result) */
-	gchar		*real_source_title;	/**< (optional) title of the real source */
 	gchar		*description;		/**< XHTML string containing the item's description */
 	
 	GSList		*metadata;		/**< Metadata of this item */
@@ -128,21 +125,22 @@ const gchar *	item_get_title(itemPtr item);
 const gchar *	item_get_description(itemPtr item);
 /** Returns the source of item. */
 const gchar *	item_get_source(itemPtr item);
-/** Returns the real source of item. */
-const gchar *	item_get_real_source_url(itemPtr item);
-/** Returns the real source title of item. */
-const gchar *	item_get_real_source_title(itemPtr item);
 
 /** Sets the item title */
 void		item_set_title(itemPtr item, const gchar * title);
-/** Sets the item description */
-void		item_set_description(itemPtr item, const gchar * description);
+
+/**
+ * Sets the item description. If called more than once it
+ * will merge the new description against the old one deciding
+ * on the best to keep.
+ *
+ * @param item		the item
+ * @param description	the content
+ */
+void item_set_description (itemPtr item, const gchar *description);
+
 /** Sets the item source */
 void		item_set_source(itemPtr item, const gchar * source);
-/** Sets the item real source */
-void		item_set_real_source_url(itemPtr item, const gchar * source);
-/** Sets the item real source title */
-void		item_set_real_source_title(itemPtr item, const gchar * source);
 /** Sets the item id */
 void		item_set_id(itemPtr item, const gchar * id);
 
