@@ -1,7 +1,8 @@
 /**
- * @file metadata.h Metadata storage API
+ * @file metadata.h  handling of typed item and feed metadata
  *
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2008 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +24,8 @@
 
 #include <glib.h>
 #include <libxml/tree.h>
-#include "feed.h"
+
+#include "feed_parser.h"
 
 /* -------------------------------------------------------- */
 /* interface definitions for namespace parsing handler      */
@@ -37,22 +39,13 @@ typedef void	(*parseItemTagFunc)	(feedParserCtxtPtr ctxt, xmlNodePtr cur);
 
 /** struct used to register namespace handler */
 typedef struct NsHandler {
-	gchar			*prefix;		/**< namespace prefix */
+	const gchar		*prefix;		/**< namespace prefix */
 	registerNsFunc		registerNs;
 	
 	parseItemTagFunc	parseItemTag;		/**< item tag parsing method */
 	parseChannelTagFunc	parseChannelTag;	/**< channel tag parsing method */
 } NsHandler;
 
-/* -------------------------------------------------------- */
-/* interface definitions for namespace rendering handler    */
-/* -------------------------------------------------------- */
-
-/** 
- * Initialize the metadata types to allow format checks.
- */
-void metadata_init(void);
-
 /** 
  * Appends a value to the value list of a specific metadata type 
  * Don't mix this function with metadata_list_set() !
