@@ -31,35 +31,29 @@
 #include "debug.h"
 #include "node.h"
 #include "plugin.h"
-#include "ui/ui_htmlview.h"
-#include "fl_sources/node_source.h"
-#include "notification/notif_plugin.h"
-
-/* plugin managment */
+#include "notification/notification.h"
 
 /** list of all loaded plugins */
 static GSList *plugins = NULL;
 
 typedef	pluginPtr (*infoFunc)();
 
-static pluginPtr plugin_mgmt_load(const gchar * filename) {
+static pluginPtr
+plugin_mgmt_load (const gchar * filename)
+{
 	pluginPtr	plugin = NULL;
 	GModule		*handle = NULL;
 	infoFunc	plugin_get_info;
 	gboolean	success = FALSE;
 	gchar		*path;
 
-	path = g_strdup_printf(PACKAGE_LIB_DIR G_DIR_SEPARATOR_S "%s", filename);
+	path = g_build_filename (PACKAGE_LIB_DIR, filename, NULL);
 
-#if GLIB_CHECK_VERSION(2,3,3)
-	handle = g_module_open(path, G_MODULE_BIND_LOCAL);
-#else
-	handle = g_module_open(path, 0);
-#endif
+	handle = g_module_open (path, G_MODULE_BIND_LOCAL);
 
-	g_free(path);
+	g_free (path);
 
-	if(!handle) {
+	if (!handle) {
 		debug3(DEBUG_PLUGINS, "Cannot open %s%s (%s)!", PACKAGE_LIB_DIR G_DIR_SEPARATOR_S, filename, g_module_error());
 		return NULL;
 	}
@@ -76,9 +70,6 @@ static pluginPtr plugin_mgmt_load(const gchar * filename) {
 				case PLUGIN_TYPE_NOTIFICATION:
 					success = notification_plugin_register (plugin, handle);
 					break;
-				case PLUGIN_TYPE_HTML_RENDERER:
-					success = liferea_htmlview_plugin_register (plugin, handle);
-					break;
 				default:
 					if(plugin->type >= PLUGIN_TYPE_MAX) {
 						debug3(DEBUG_PLUGINS, "Unknown or unsupported plugin type: %s (%s, type=%d)", plugin->name, filename, plugin->type);
@@ -160,10 +151,7 @@ void plugin_mgmt_init(void) {
 		error = NULL;
 	}
 
-	g_assert(NULL != plugins);
-	
 	/* do plugin type specific startup init */
-	liferea_htmlview_plugin_init ();
 	notification_plugin_init ();
 
 	debug_exit("plugin_mgmt_init");
