@@ -101,6 +101,7 @@ typedef struct updateRequest {
 					     filename. Eventually, everything should be a
 					     URL. Use file:// and exec:// */
 	gchar           *postdata;      /**< HTTP POST request data (NULL for non-POST requests) */
+	gchar           *authValue;     /**< Custom value for Authorization: header */
 	updateOptionsPtr options;	/**< Update options for the request */
 	gchar		*filtercmd;	/**< Command will filter output of URL */
 	gboolean	allowRetries;	/**< Allow download retries on network errors */
@@ -208,7 +209,15 @@ void update_request_free (updateRequestPtr request);
  * @param request       the update request
  * @param source        the new source
  */
-void update_request_set_source(updateRequestPtr request, gchar* source);
+void update_request_set_source(updateRequestPtr request, const gchar* source);
+
+/**
+ * Sets a custom authorization header value.
+ *
+ * @param request        the update request
+ * @param authValue      the authorization header value
+ */
+void update_request_set_auth_value(updateRequestPtr request, const gchar* authValue);
 
 /**
  * Creates a new update result for the given update request.
