@@ -1,7 +1,7 @@
 /**
- * @file vfolder.c search folder node type
+ * @file vfolder.c  search folder node type
  *
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,10 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
 #include "common.h"
 #include "conf.h"
 #include "db.h"
@@ -31,8 +27,10 @@
 #include "itemlist.h"
 #include "node.h"
 #include "vfolder.h"
+#include "ui/ui_common.h"
+#include "ui/ui_feedlist.h"
 #include "ui/ui_node.h"
-#include "ui/ui_vfolder.h"
+#include "ui/search_folder_dialog.h"
 
 /** The list of all existing vfolders. Used for updating vfolder information upon item changes */
 static GSList		*vfolders = NULL;
@@ -46,11 +44,11 @@ vfolder_new (nodePtr node)
 
 	vfolder = g_new0 (struct vfolder, 1);
 	vfolder->node = node;
+	vfolder->anyMatch = TRUE;
 	vfolders = g_slist_append (vfolders, vfolder);
 
 	if (!node->title)
 		node_set_title (node, _("New Search Folder"));	/* set default title */
-	node_set_type (node, vfolder_get_node_type());
 	node_set_data (node, (gpointer) vfolder);
 
 	debug_exit ("vfolder_new");
@@ -62,8 +60,18 @@ static void
 vfolder_import_rules (xmlNodePtr cur,
                       vfolderPtr vfolder)
 {
-	xmlChar		*type, *ruleId, *value, *additive;
+	xmlChar		*matchType, *type, *ruleId, *value, *additive;
 	
+	matchType = xmlGetProp (cur, BAD_CAST"matchType");
+	if (matchType) {
+		/* currently we now only OR or AND'ing the rules,
+		   "any" is the value for OR'ing, "all" for AND'ing */
+		vfolder->anyMatch = (0 != xmlStrcmp (matchType, BAD_CAST"all"));
+	} else {
+		vfolder->anyMatch = TRUE;
+	}
+	xmlFree (matchType);
+
 	/* process any children */
 	cur = cur->xmlChildrenNode;
 	while (cur) {
@@ -105,8 +113,17 @@ vfolder_load (nodePtr node)
 void
 vfolder_update_counters (nodePtr node) 
 {
-	node->unreadCount = db_view_get_unread_count (node->id);
-	node->itemCount = db_view_get_item_count (node->id);
+	vfolderPtr vfolder = (vfolderPtr)node->data;
+	
+	/* Avoid throwing a "view unread count failed (error code 101, not an error)"
+	   warning in the database when there are no rules yet. */
+	if (vfolder->rules) {
+		node->unreadCount = db_view_get_unread_count (node->id);
+		node->itemCount = db_view_get_item_count (node->id);
+	} else {
+		node->unreadCount = 0;
+		node->itemCount = 0;
+	}
 	ui_node_update (node->id);
 }
 
@@ -116,7 +133,7 @@ vfolder_refresh (vfolderPtr vfolder)
 	g_return_if_fail (NULL != vfolder->node);
 
 	if (0 != g_slist_length (vfolder->rules))
-		rules_to_view (vfolder->rules, vfolder->node->id);
+		rules_to_view (vfolder->rules, vfolder->anyMatch, vfolder->node->id);
 	
 	vfolder_update_counters (vfolder->node);
 }
@@ -179,7 +196,6 @@ vfolder_import (nodePtr node,
 
 	vfolder = vfolder_new (node);
 	vfolder_import_rules (cur, vfolder);
-	node_add_child (parent, node, -1);
 	vfolder_refresh (vfolder);
 }
 
@@ -196,6 +212,8 @@ vfolder_export (nodePtr node,
 	debug_enter ("vfolder_export");
 	
 	g_assert (TRUE == trusted);
+	
+	xmlNewProp (cur, BAD_CAST"matchType", BAD_CAST (vfolder->anyMatch?"any":"all"));
 
 	iter = vfolder->rules;
 	while (iter) {
@@ -218,9 +236,12 @@ vfolder_export (nodePtr node,
 	debug_exit ("vfolder_export");
 }
 
-/* Method thats adds a rule to a vfolder. To be used
-   on loading time or when creating searching. Does 
-   not process items. Just sets up the vfolder */
+void
+vfolder_add_existing_rule (vfolderPtr vfolder, rulePtr rule)
+{
+	vfolder->rules = g_slist_append (vfolder->rules, rule);
+}
+
 void
 vfolder_add_rule (vfolderPtr vfolder,
                   const gchar *ruleId,
@@ -230,15 +251,12 @@ vfolder_add_rule (vfolderPtr vfolder,
 	rulePtr		rule;
 	
 	rule = rule_new (vfolder, ruleId, value, additive);
-	if(rule)
-		vfolder->rules = g_slist_append(vfolder->rules, rule);
+	if (rule)
+		vfolder_add_existing_rule (vfolder, rule);
 	else
-		g_warning("unknown search folder rule id: \"%s\"", ruleId);
+		g_warning ("unknown search folder rule id: \"%s\"", ruleId);
 }
 
-/* Method that remove a rule from a vfolder. To be used
-   when deleting or changing vfolders. Does not process
-   items. */
 void
 vfolder_remove_rule (vfolderPtr vfolder, rulePtr rule) 
 {
@@ -280,14 +298,32 @@ vfolder_update_unread_count (nodePtr node)
 static void
 vfolder_remove (nodePtr node) 
 {
-	ui_node_remove_node (node);
-	vfolder_free (node);
+	db_view_remove (node->id);
+}
+
+static void
+vfolder_properties (nodePtr node)
+{
+	search_folder_dialog_new (node);
+}
+
+static gboolean
+vfolder_add (void)
+{
+	nodePtr	node;
+
+	node = node_new (vfolder_get_node_type ());
+	vfolder_new (node);
+	vfolder_properties (node);
+	
+	return TRUE;
 }
 
 nodeTypePtr
 vfolder_get_node_type (void)
 { 
 	static struct nodeType nti = {
+		NODE_CAPABILITY_SHOW_ITEM_FAVICONS |
 		NODE_CAPABILITY_SHOW_UNREAD_COUNT |
 		NODE_CAPABILITY_SHOW_ITEM_COUNT,
 		"vfolder",
@@ -297,11 +333,10 @@ vfolder_get_node_type (void)
 		vfolder_load,
 		vfolder_save,
 		vfolder_update_unread_count,
-		NULL,			/* process_update_result() */
 		vfolder_remove,
 		node_default_render,
-		ui_vfolder_add,
-		ui_vfolder_properties,
+		vfolder_add,
+		vfolder_properties,
 		vfolder_free
 	};
 	nti.icon = icons[ICON_VFOLDER];
